@@ -1,7 +1,4 @@
 package Modern::Perl;
-{
-  $Modern::Perl::VERSION = '1.20121103';
-}
 # ABSTRACT: enable all of the features of Modern Perl with one import
 
 use 5.010_000;
@@ -27,7 +24,7 @@ sub VERSION
     return $VERSION if             $version < 2009;
 
     $wanted_date = $version if (caller(1))[3] =~ /::BEGIN/;
-    return 2012;
+    return 2016;
 }
 
 sub import
@@ -38,8 +35,8 @@ sub import
     my $feature_tag    = validate_date( $date );
     undef $wanted_date;
 
-    warnings->import();
-    strict->import();
+    warnings->import;
+    strict->import;
     feature->import( $feature_tag );
     mro::set_mro( scalar caller(), 'c3' );
 }
@@ -58,6 +55,9 @@ my %dates =
     2011 => ':5.12',
     2012 => ':5.14',
     2013 => ':5.16',
+    2014 => ':5.18',
+    2015 => ':5.20',
+    2016 => ':5.24',
 );
 
 sub validate_date
@@ -84,13 +84,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 Modern::Perl - enable all of the features of Modern Perl with one import
 
 =head1 VERSION
 
-version 1.20121103
+version 1.20161005
 
 =head1 SYNOPSIS
 
@@ -133,20 +135,27 @@ optional import tag. For example:
 
     use Modern::Perl '2012';
 
-... enables 5.14 features, and:
+... enables 5.14 features:
 
     use Modern::Perl '2013';
 
-... enables 5.16 features. Obviously you cannot use newer features on earlier
+... enables 5.16 features, and:
+
+    use Modern::Perl '2014';
+
+... enables 5.18 features, and:
+
+    use Modern::Perl '2015';
+
+... enables 5.20 features, and:
+
+    use Modern::Perl '2016';
+
+... enables 5.24 features.
+
+Obviously you cannot use newer features on earlier
 versions. Perl will throw the appropriate exception if you try.
 
-In the near future--sometime around September 2012--this module may drop
-support for 5.10 and will complain (once per process) if you use a year too
-old. As of May 2012, Perl 5.12 is unsupported by the Perl 5 Porters, so please
-consider upgrading.
-
-=encoding utf8
-
 =head1 AUTHOR
 
 chromatic, C<< <chromatic at wgz.org> >>
@@ -200,10 +209,10 @@ features.
 
 =head1 COPYRIGHT & LICENSE
 
-Copyright 2009-2012 chromatic, all rights reserved.
+Copyright 2009-2016 chromatic, all rights reserved.
 
 This program is free software; you can redistribute it and/or modify it
-under the same terms as Perl 5.14 itself.
+under the same terms as Perl 5.18 itself.
 
 =head1 AUTHOR
 
@@ -211,7 +220,7 @@ chromatic
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by chromatic@wgz.org.
+This software is copyright (c) 2016 by chromatic@wgz.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
